@@ -1036,7 +1036,7 @@ class ETSModel(base.StateSpaceMLEModel):
 
             # check if we have fixed parameters and remove them from the
             # parameter vector
-            is_fixed = np.zeros(self._k_params_internal, dtype=int)
+            is_fixed = np.zeros(self._k_params_internal, dtype=np.int64)
             fixed_values = np.empty_like(internal_start_params)
             params_without_fixed = []
             kwargs["bounds"] = []
@@ -1142,10 +1142,12 @@ class ETSModel(base.StateSpaceMLEModel):
             data = self.endog
 
         if is_fixed is None:
-            is_fixed = np.zeros(self._k_params_internal, dtype=int)
+            is_fixed = np.zeros(self._k_params_internal, dtype=np.int64)
             fixed_values = np.empty(
                 self._k_params_internal, dtype=params.dtype
             )
+        else:
+            is_fixed = np.ascontiguousarray(is_fixed, dtype=np.int64)
 
         self._smoothing_func(
             params,
@@ -1165,7 +1167,7 @@ class ETSModel(base.StateSpaceMLEModel):
             # parameterizations, we clip negative values to very small positive
             # values so that the log-transformation yields very large negative
             # values.
-            yhat[yhat <= 0] = 1 / (1e-8 * (1 + np.abs(yhat[yhat < 0])))
+            yhat[yhat <= 0] = 1 / (1e-8 * (1 + np.abs(yhat[yhat <= 0])))
             logL -= np.sum(np.log(yhat))
         return logL
 
@@ -1250,7 +1252,7 @@ class ETSModel(base.StateSpaceMLEModel):
         internal_params = self._internal_params(params)
         yhat = np.zeros(self.nobs)
         xhat = np.zeros((self.nobs, self._k_states_internal))
-        is_fixed = np.zeros(self._k_params_internal, dtype=int)
+        is_fixed = np.zeros(self._k_params_internal, dtype=np.int64)
         fixed_values = np.empty(self._k_params_internal, dtype=params.dtype)
         self._smoothing_func(
             internal_params, self.endog, yhat, xhat, is_fixed, fixed_values
@@ -1772,7 +1774,7 @@ class ETSResults(base.StateSpaceMLEResults):
         start_params = self._get_prediction_params(start_idx)
         x = np.zeros((nsimulations, self.model._k_states_internal))
         # is fixed and fixed values are dummy arguments
-        is_fixed = np.zeros(len(start_params), dtype=int)
+        is_fixed = np.zeros(len(start_params), dtype=np.int64)
         fixed_values = np.zeros_like(start_params)
         (
             alpha,
